local json = require("json")
local utils = require("utils")
local const = require("const")
--local resty_string = require("resty.string")
--local resty_random = require("resty.random")

local COOKIE_MAX_AGE = 360

local memkv = ngx.shared.memkv
local request_method = ngx.var.request_method

utils.check_login()
local _, login_token = utils.check_permission("GatewayManage")
local login_username = memkv:get(login_token .. "." .. "username")

--local function hash_passwd(passwd)
--    local salt = resty_string.to_hex(resty_random.bytes(16))
--    local hex = utils.hmac_sha256(salt, passwd)
--    if not hex then
--        return false, "hmac sha256 failed"
--    end
--    return true, salt, resty_string.to_hex(hex)
--end

if request_method == "POST" then
    --[[
        "User": string["admin"],
        "Password": string,
        "ProductKey": string,
        "DeviceName": string,
        "DeviceSecret": string,
        "DeviceAuthMode": string["Auto", "Manual"], //配置子设备接入方式；Auto：无需认证，自动接入；Manual：自动接入的设备需在控制台上确认
        "ChannelQos": int[0, 1, 2] //可选参数，暂时不用
    --]]
    ngx.req.read_body()
    local args_str = ngx.req.get_body_data()
    local ok, args = pcall(json.decode, args_str)
    if not ok then
        return utils.error_exit(400, "not a JSON")
    end

    local username = args["User"]
    if username ~= login_username then
        return utils.error_exit(400, "mismatch username")
    end

    if username ~= "admin" then
        return utils.error_exit(400, "only admin can configure gateway")
    end

    --local passwd = args["Password"]
    local product = args["ProductKey"]
    local device = args["DeviceName"]
    local secret = args["DeviceSecret"]
    --local auth_mode = args["DeviceAuthMode"]
    --utils.check_username(username)
    --utils.check_passwd(passwd)
    utils.check_pk(product)
    utils.check_dn(device)
    utils.check_ds(secret)
    --utils.check_authmode(auth_mode)

    --local ok, user_data = utils.get_data(const.data_key.eweb.user)
    --if not ok then
    --    utils.log_info("get user list failed: " .. user_data)
    --    return utils.error_exit(500, "get user list failed: " .. user_data)
    --end
    --local ok, user_list = pcall(json.decode, user_data)
    --if not ok then
    --    utils.log_info("parse user list failed: not a JSON")
    --    return utils.error_exit(500, "parse user list failed: not a JSON")
    --end
    --
    --if next(user_list["UserList"]) == nil or user_list["UserList"][username] == nil then
    --    utils.log_info("invalid user list")
    --    return utils.error_exit(500, "invalid user list")
    --end
    --
    --if (string.len(passwd) > 20) then
    --    utils.log_info("Password exceeds maximum length")
    --    return utils.error_exit(400, "Password exceeds maximum length")
    --end
    --
    --local user_info = {}
    --local ok, salt, passwd_hash = hash_passwd(passwd)
    --if not ok then
    --    utils.log_info("encrypt Password failed")
    --    return utils.error_exit(500, "encrypt Password failed")
    --end
    --user_info["PasswordSalt"] = salt
    --user_info["PasswordHash"] = passwd_hash
    --
    --user_info["Username"] = username
    ---- TODO hide ComputeManage module
    ----user_info["Permission"] = {"GatewayManage", "DeviceManage", "DriverManage", "ComputeManage", "LogManage", "UserManage"}
    --user_info["Permission"] = {"MessageRoute", "TSLManage", "StreamCompute","GatewayManage", "DeviceManage", "DriverManage", "LogManage", "UserManage"}
    --user_info["LastLoginTime"] = tostring(os.time())
    --
    --user_list["UserList"][username] = user_info
    --local updated_user_list = json.encode(user_list)
    --utils.log_info("updated user list:", updated_user_list)
    --local ok, err_u = utils.set_data(const.data_key.eweb.user, updated_user_list)
    --if not ok then
    --    utils.log_error("save user list failed: " .. err_u)
    --    return utils.error_exit("save user list failed")
    --end
    ---- update the user's permissions
    --local permissions = ""
    --for _, val in ipairs(user_info["Permission"]) do
    --    permissions = val .. "," .. permissions
    --end
    --memkv:set(login_token, permissions, COOKIE_MAX_AGE)

    local ok, err_t = utils.set_gw_triple(product, device, secret)
    if not ok then
        return utils.error_exit(500, "set triple failed: " .. err_t)
    end
    return utils.error_exit(200)
elseif "GET" == request_method then
    local ok, msg_user = utils.get_data(const.data_key.eweb.user)
    if (not ok) then
        utils.log_error("get user data failed" .. msg_user .. msg_gwconfig)
        utils.error_exit(500, "get data fail")
    end

    if (nil == msg_user) then 
        utils.error_exit(400, "gateway have not been initialized")
    end

    local user_data = json.decode(msg_user)
    local user_info = user_data["UserList"]["admin"]
    if (nil == user_info) then
        utils.error_exit(500, "user info is incorrect.")
    end

    local res = {}
    res["User"] = "admin"
    res["PasswordHash"] = user_info["PasswordHash"]
    res["LastLoginTime"] = user_info["LastLoginTime"]

    local pk, dn, ds, auth_mode = utils.get_gw_config()
    res["ProductKey"] = pk
    res["DeviceName"] = dn
    res["DeviceSecret"] = ds
    res["DeviceAuthMode"] = auth_mode
    res["DeviceTags"] = utils.get_device_tags(pk, dn)
    res_raw = json.encode(res)
    utils.error_exit(200, res_raw)
end

utils.error_exit(400, "unsupported request method")

------ EOF ------
