local json = require("json")
local utils = require("utils")
local driver_utils = require("driver_utils")
local request_method = ngx.var.request_method

utils.check_login()
utils.check_permission("DriverManage")

if request_method ~= "POST" then
    return utils.error_exit(405, "unsupported request method: " .. request_method)
end

local utils_header = require("utils_header")
utils_header.check_public_body_data()

local drivers, err = driver_utils.get_driver_list2()
if drivers == nil then
    return utils.error_exit(500, err)
end

local resp = {
    code = 200,
    message = "success",
    data = {}
}
for _, v in ipairs(drivers) do
    local item = {
        DriverId = v.id,
        DriverName = v.name,
        DriverMode = v.mode,
        DriverState = v.state,
        Runtime = v.runtime,
    }
    table.insert(resp.data, item)
end
ngx.say(json.encode(resp))
