local json = require("json")
local utils = require("utils")

utils.check_login()
utils.check_permission("DriverManage")

local request_method = ngx.var.request_method
if request_method ~= "POST" then
    return utils.error_exit(405, "unsupported request method: " .. request_method)
end

local function response(config)
    local resp = {}
    resp["code"] = 200
    resp["message"] = "success"
    resp["data"] = { DriverConfig = config }
    ngx.say(json.encode(resp))
end

local utils_header = require("utils_header")
local params = utils_header.check_public_body_data()

local driver_name = params["DriverName"]
if type(driver_name) == "string" and driver_name == "gateway_monitor" then
    response({ config = {}})
    return
end

local driver_id = params["DriverId"]
if type(driver_id) ~= "string" or #driver_id == 0 then
    utils.error_exit(400, "driver id is not string or is empty")
end
local msg, err = utils.get_driver_config(driver_id)
if msg == nil then
    utils.error_exit(500, err)
end
local ok, config = pcall(json.decode, msg)
if not ok then
    return utils.error_exit(500, "config not in JSON")
end
response(config)