#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# ====#====#====#====
# author = "jys"
# file: ut_dimu.py
# time: 1/17/18 2:57 AM
# ====#====#====#====

import sys

sys.path.append("../../lib/")
from leda_python.mbus import MbusBase
from gi.repository import GLib
import dbus.mainloop.glib
import dbus.service
import threading
import logging
import json
import time
import dbus
import os
import signal

DIMU_WELL_KNOWN_NAME = "iot.dmp.dimu"
DIMU_OBJECT_PATH = "/iot/dmp/dimu"
DIMU_INTERFACE = "iot.dmp.dimu"

_logger = logging.getLogger(__name__)


class MbusObject(dbus.service.Object):
    def __init__(self, conn, objPath):
        super(MbusObject, self).__init__(conn, objPath)

    @dbus.service.method(DIMU_INTERFACE, in_signature='s', out_signature='s')
    def registerDriver(self, inparams):
        inMsgDict = json.loads(inparams)

        _logger.debug("the registerDriver: %s", inMsgDict)

        retJson = {
            "code": 123,
            "message": "success",
            "params": {
            }
        }

        return json.dumps(retJson)

    @dbus.service.method(DIMU_INTERFACE, in_signature='s', out_signature='s')
    def unregisterDriver(self, inparams):
        inMsgDict = json.loads(inparams)

        _logger.debug("the unregisterDriver: %s", inMsgDict)

        retJson = {
            "code": 123,
            "message": "success",
            "params": {
            }
        }

        return json.dumps(retJson)

    @dbus.service.method(DIMU_INTERFACE, in_signature='s', out_signature='s')
    def registerDevice(self, inparams):
        inMsgDict = json.loads(inparams)
        _logger.debug("registerDevice inparms")
        _logger.debug("\tdevice.productKey: %s", inMsgDict["productKey"])
        _logger.debug("\tdevice.deviceLocalId: %s", inMsgDict["deviceLocalId"])
        _logger.debug("\tdevice.productMD5: %s", inMsgDict["productMD5"])
        _logger.debug("\tdevice.deviceProfile: %s", inMsgDict["deviceProfile"])
        _logger.debug("\tdevice.isLocal: %s", inMsgDict["isLocal"])

        cloudId = inMsgDict["productKey"] + '_' + inMsgDict["deviceLocalId"]
        code = 1

        retJson = {
            "code": code,
            "message": "success",
            "params": {
                "deviceCloudId": cloudId
            }
        }

        return json.dumps(retJson)

    @dbus.service.method(DIMU_INTERFACE, in_signature='s', out_signature='s')
    def unregisterDevice(self, inparams):
        _logger.debug("unregisterDevice inparms")
        retJson = {
            "code": 1,
            "message": 'succcess'
        }

        return json.dumps(retJson)

    @dbus.service.method(DIMU_INTERFACE, in_signature='s', out_signature='s')
    def connect(self, inparams):
        inMsgDict = json.loads(inparams)

        code = 1

        cloudId = inMsgDict["productKey"] + '_' + inMsgDict["deviceName"]
        _logger.debug("the online device: %s, time: %s, ", cloudId, time.time())
        retJson = {
            "code": code,
            "message": 'success',
            "params": {
                "deviceCloudId": cloudId,
            }
        }

        return json.dumps(retJson)

    @dbus.service.method(DIMU_INTERFACE, in_signature='s', out_signature='s')
    def disconnect(self, inparams):
        _logger.debug("the offline device: %s", inparams)

        code = 1

        retJson = {
            "code": code,
            "message": "success"
        }

        return json.dumps(retJson)


def createThread(task, args=()):
    t = threading.Thread(target=task, args=args)
    t.setDaemon(True)
    t.start()


g_Flag = False


def Task_mainLoop():
    mainloop = GLib.MainLoop()
    mainloop.run()


def Signal_handle(signum, frame):
    global g_Flag
    print('recv a signal: %s' % (frame))
    g_Flag = True


if (__name__ == "__main__"):
    os.system(
        "ps -ef | grep \"bin/dimu\" | grep -v \"grep\" | awk \'{print $2}\' | xargs kill -9 1>> /dev/null 2>>/dev/null")
    logging.basicConfig(level=logging.DEBUG)
    dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
    mbusConnectObject = MbusBase(DIMU_WELL_KNOWN_NAME)
    bus = mbusConnectObject.getBus()

    instance = MbusObject(bus, DIMU_OBJECT_PATH)
    createThread(Task_mainLoop)
    signal.signal(signal.SIGINT, Signal_handle)
    while (1):
        time.sleep(0.5)
        if (g_Flag): break
